@@ -35,6 +35,10 @@ class Payment:
             'establishment_name': 'Cadena',  # opcional
             'sub_payments': []
         }
+        if 'sub_payments' in payment_data:
+            body['sub_payments'] = payment_data['sub_payments']
+        if 'payment_type' in payment_data:
+            body['payment_type'] = payment_data['payment_type']
         r = requests.post(self.url + '/payments', headers=self.headers, data=json.dumps(body))
         response = r.json()
         response['processor'] = 'decidir'
