@@ -6,9 +6,12 @@ from .Payment import Payment
 
 
 class MercadoPagoSDK:
-    def __init__(self, merchant):
+    def __init__(self, merchant, marketplace=False):
         if 'credentials' in merchant:
-            access_token = merchant['credentials']['mercadopago']['access_token']
+            if not marketplace:
+                access_token = merchant['credentials']['mercadopago']['access_token']
+            else:
+                access_token = merchant['credentials']['mp_marketplace']['access_token']
         else:
             access_token = merchant['keys']['access_token']
         self.sdk = mercadopago.SDK(access_token)
